@@ -18,10 +18,13 @@ fn main() {
     println!("cargo:rustc-check-cfg=cfg(Py_3_11)");
     println!("cargo:rustc-check-cfg=cfg(Py_3_12)");
     println!("cargo:rustc-check-cfg=cfg(Py_3_13)");
+    println!("cargo:rustc-check-cfg=cfg(Py_3_14)");
     println!("cargo:rustc-check-cfg=cfg(Py_3_8)");
     println!("cargo:rustc-check-cfg=cfg(Py_3_9)");
+    println!("cargo:rustc-check-cfg=cfg(Py_GIL_DISABLED)");
 
-    for cfg in pyo3_build_config::get().build_script_outputs() {
+    let python_config = pyo3_build_config::get();
+    for cfg in python_config.build_script_outputs() {
         println!("{cfg}");
     }
 
@@ -33,17 +36,27 @@ fn main() {
         println!("cargo:rustc-cfg=feature=\"optimize\"");
     }
 
-    if let Some(true) = version_check::supports_feature("strict_provenance") {
-        println!("cargo:rustc-cfg=feature=\"strict_provenance\"");
-    }
-
     #[cfg(any(target_arch = "x86_64", target_arch = "aarch64"))]
     if env::var("ORJSON_DISABLE_SIMD").is_err() {
+        // auto build unstable SIMD on nightly
         if let Some(true) = version_check::supports_feature("portable_simd") {
             println!("cargo:rustc-cfg=feature=\"unstable-simd\"");
         }
+        // auto build AVX512 on x86-64-v4 or supporting native targets
+        #[cfg(all(target_arch = "x86_64", target_feature = "avx512vl"))]
+        if let Some(true) = version_check::supports_feature("stdarch_x86_avx512") {
+            if env::var("ORJSON_DISABLE_AVX512").is_err() {
+                println!("cargo:rustc-cfg=feature=\"avx512\"");
+            }
+        }
     }
 
+    #[cfg(all(
+        target_pointer_width = "64",
+        any(target_arch = "x86_64", target_arch = "aarch64")
+    ))]
+    println!("cargo:rustc-cfg=feature=\"inline_int\"");
+
     if env::var("ORJSON_DISABLE_YYJSON").is_ok() {
         if env::var("CARGO_FEATURE_YYJSON").is_ok() {
             panic!("ORJSON_DISABLE_YYJSON and --features=yyjson both enabled.")
