@@ -100,6 +100,15 @@
 //! lto = "thin"
 //! ```
 //!
+//! If thin LTO isn't cutting it, the next thing to try would be fat LTO with a
+//! single codegen unit:
+//!
+//! ```toml
+//! [profile.release]
+//! lto = "fat"
+//! codegen-units = 1
+//! ```
+//!
 //! If you want no_panic to just assume that some function you call doesn't
 //! panic, and get Undefined Behavior if it does at runtime, see
 //! [dtolnay/no-panic#16]; try wrapping that call in an `unsafe extern "C"`
@@ -117,7 +126,8 @@
 //! [Kixunil]: https://github.com/Kixunil
 //! [`dont_panic`]: https://github.com/Kixunil/dont_panic
 
-#![doc(html_root_url = "https://docs.rs/no-panic/0.1.28")]
+#![doc(html_root_url = "https://docs.rs/no-panic/0.1.30")]
+#![cfg_attr(not(check_cfg), allow(unexpected_cfgs))]
 #![allow(
     clippy::doc_markdown,
     clippy::match_same_arms,
@@ -165,6 +175,7 @@ fn parse(args: TokenStream2, input: TokenStream2) -> Result<ItemFn> {
 // Convert `Path<impl Trait>` to `Path<_>`
 fn make_impl_trait_wild(ret: &mut Type) {
     match ret {
+        #![cfg_attr(all(test, exhaustive), deny(non_exhaustive_omitted_patterns))]
         Type::ImplTrait(impl_trait) => {
             *ret = Type::Infer(TypeInfer {
                 underscore_token: Token![_](impl_trait.impl_token.span),
@@ -186,7 +197,6 @@ fn make_impl_trait_wild(ret: &mut Type) {
         }
         Type::Tuple(ret) => ret.elems.iter_mut().for_each(make_impl_trait_wild),
         Type::BareFn(_) | Type::Infer(_) | Type::Macro(_) | Type::Never(_) | Type::Verbatim(_) => {}
-        #[cfg_attr(all(test, exhaustive), deny(non_exhaustive_omitted_patterns))]
         _ => {}
     }
 }
